#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Links Puzzle
# send your bug reports to contact@dotslashplay.it
###

script_version=20241217.1

PLAYIT_COMPATIBILITY_LEVEL='2.31'

GAME_ID='links-puzzle'
GAME_NAME='Links Puzzle'

ARCHIVE_BASE_1_NAME='setup_links_puzzle_1.0.2_(72721).exe'
ARCHIVE_BASE_1_MD5='5bc0a87e2bdfcf204feda0cb3d3e9ad8'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_SIZE='26071'
ARCHIVE_BASE_1_VERSION='1.0.2-gog72721'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/links_puzzle'

ARCHIVE_BASE_0_NAME='setup_links_puzzle_1.0.1_(70326).exe'
ARCHIVE_BASE_0_MD5='60c9021cdf833b2ee3feeead1f0ffe56'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='24412'
ARCHIVE_BASE_0_VERSION='1.0.1-gog70326'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_BIN_FILES='
almixer.dll
coronalabs.corona.native.dll
lua.dll
openal32.dll
plugin_hwcursor.dll
pthreads.dll
links puzzle.exe'
CONTENT_GAME_DATA_FILES='
resources'

WINE_PERSISTENT_DIRECTORIES='
users/${USER}/AppData/Roaming/AleC Games/Links Puzzle
users/${USER}/AppData/Local/AleC Games/Links Puzzle'

APP_MAIN_EXE='links puzzle.exe'
APP_MAIN_ICON='resources/icon-win32.ico'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='32'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=libplayit2.sh
. "$PLAYIT_LIB2"

# Run the default initialization actions

initialization_default "$@"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers

launchers_generation 'PKG_BIN'

# Build packages

packages_generation
print_instructions

# Clean up

working_directory_cleanup

exit 0
